==> haskell-special-values-0.1.0.0-270-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-8ExFSqISk6W82hztEdyNuM
key:                  special-values-0.1.0.0-8ExFSqISk6W82hztEdyNuM
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  78322c1c0c5728979ad78fd36aea8c95
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-8ExFSqISk6W82hztEdyNuM
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    scientific-0.3.8.0-5VCcSe8kMhaKTje3aOa6OL text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-special-values-0.1.0.0-271-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-special-values.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 special-values
version:              0.1.0.0
visibility:           public
id:                   special-values-0.1.0.0-9rGQWO4kMhf5PfT9eHudIb
key:                  special-values-0.1.0.0-9rGQWO4kMhf5PfT9eHudIb
license:              MIT
copyright:            2017 Daniel Mendler
maintainer:           Daniel Mendler <mail@daniel-mendler.de>
author:               Daniel Mendler <mail@daniel-mendler.de>
homepage:             https://github.com/minad/special-values#readme
synopsis:             Typeclass providing special values
description:
    Special values are provided by a SpecialValues typeclass. Those can be used for example by QuickCheck, see quickcheck-special.

category:             Testing
abi:                  d1cd92e2503496855a81b947d2d705ad
exposed:              True
exposed-modules:      Data.SpecialValues
hidden-modules:       Paths_special_values
import-dirs:          /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/special-values-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-special-values
hs-libraries:         HSspecial-values-0.1.0.0-9rGQWO4kMhf5PfT9eHudIb
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    scientific-0.3.8.0-ECM1X4w9aCV1oDTMJMlYIW text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-special-values/html/special-values.haddock

haddock-html:         /usr/share/doc/haskell-special-values/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
